==> blesta-5.10.2.zip: blesta/language/cs_cz/admin_company_groups.php <==
<?php
/**
 * Admin Company Groups
 *
 * @package blesta
 * @subpackage blesta.language.cs_cz
 * @copyright Copyright (c) 2024, Phillips Data, Inc.
 * @license http://www.blesta.com/license/ The Blesta License Agreement
 * @link http://www.blesta.com/ Blesta
 */

$lang['AdminCompanyGroups.edit.text_editsubmit'] = 'Upravit skupinu';
$lang['AdminCompanyGroups.edit.field_force_email_usernames'] = 'Vynucování e-mailových adres jako uživatelských jmen';
$lang['AdminCompanyGroups.edit.field_company_settings'] = 'Použít nastavení společnosti (zrušte zaškrtnutí a zadejte níže)';
$lang['AdminCompanyGroups.edit.field_delivery_methods'] = 'Způsoby doručování faktur';
$lang['AdminCompanyGroups.edit.field_description'] = 'Popis';
$lang['AdminCompanyGroups.edit.field_color'] = 'Barva';
$lang['AdminCompanyGroups.edit.field_name'] = 'Název';
$lang['AdminCompanyGroups.edit.heading_client_fields'] = 'Povinná pole klienta';
$lang['AdminCompanyGroups.edit.heading_client_settings'] = 'Obecná nastavení klienta';
$lang['AdminCompanyGroups.edit.heading_payment'] = 'Oznámení';
$lang['AdminCompanyGroups.edit.heading_delivery'] = 'Dodání faktury';
$lang['AdminCompanyGroups.edit.heading_late_fees'] = 'Poplatky za zpoždění';
$lang['AdminCompanyGroups.edit.heading_invoice'] = 'Možnosti fakturace a účtování';
$lang['AdminCompanyGroups.edit.heading_basic'] = 'Základní možnosti';
$lang['AdminCompanyGroups.edit.boxtitle_editgroup'] = 'Upravit skupinu';
$lang['AdminCompanyGroups.edit.page_title'] = 'Nastavení > Společnost > Skupiny klientů > Upravit skupinu';
$lang['AdminCompanyGroups.add.text_addsubmit'] = 'Vytvořit skupinu';
$lang['AdminCompanyGroups.add.field_email_verification'] = 'Povolení ověřování e-mailu';
$lang['AdminCompanyGroups.add.field_force_email_usernames'] = 'Vynucování e-mailových adres jako uživatelských jmen';
$lang['AdminCompanyGroups.add.field_company_settings'] = 'Použít nastavení společnosti (zrušte zaškrtnutí a zadejte níže)';
$lang['AdminCompanyGroups.add.field_delivery_methods'] = 'Způsoby doručování faktur';
$lang['AdminCompanyGroups.add.field_description'] = 'Popis';
$lang['AdminCompanyGroups.add.field_color'] = 'Barva';
$lang['AdminCompanyGroups.add.field_name'] = 'Název';
$lang['AdminCompanyGroups.add.heading_client_fields'] = 'Povinná pole klienta';
$lang['AdminCompanyGroups.add.heading_client_settings'] = 'Obecná nastavení klienta';
$lang['AdminCompanyGroups.add.heading_payment'] = 'Oznámení';
$lang['AdminCompanyGroups.add.heading_delivery'] = 'Dodání faktury';
$lang['AdminCompanyGroups.add.heading_late_fees'] = 'Poplatky za zpoždění';
$lang['AdminCompanyGroups.add.heading_invoice'] = 'Možnosti fakturace a účtování';
$lang['AdminCompanyGroups.add.heading_basic'] = 'Základní možnosti';
$lang['AdminCompanyGroups.add.boxtitle_addgroup'] = 'Vytvořit skupinu';
$lang['AdminCompanyGroups.add.page_title'] = 'Nastavení > Společnost > Skupiny klientů > Vytvořit skupinu';
$lang['AdminCompanyGroups.index.confirm_delete'] = 'Opravdu chcete tuto skupinu klientů odstranit? Všichni klienti v této skupině budou přesunuti do výchozí skupiny.';
$lang['AdminCompanyGroups.index.no_results'] = 'Neexistují žádné skupiny klientů.';
$lang['AdminCompanyGroups.index.option_delete'] = 'Odstranit';
$lang['AdminCompanyGroups.index.option_edit'] = 'Upravit';
$lang['AdminCompanyGroups.index.text_options'] = 'Možnosti';
$lang['AdminCompanyGroups.index.text_clients'] = 'Počet klientů';
$lang['AdminCompanyGroups.index.text_description'] = 'Popis';
$lang['AdminCompanyGroups.index.text_name'] = 'Název';
$lang['AdminCompanyGroups.index.categorylink_addgroup'] = 'Vytvořit skupinu';
$lang['AdminCompanyGroups.index.boxtitle_groups'] = 'Skupiny klientů';
$lang['AdminCompanyGroups.index.page_title'] = 'Nastavení > Společnost > Skupiny klientů';
$lang['AdminCompanyGroups.!tooltip.email_verification'] = 'Zaškrtněte, chcete-li odeslat ověřovací e-mail při vytvoření nového přihlášení nebo při změně e-mailu klienta. Oznámení se bude zobrazovat na profilu klienta, dokud nebude ověřen.';
$lang['AdminCompanyGroups.!tooltip.force_email_usernames'] = 'Odstraňuje možnost klientů definovat vlastní uživatelské jméno.';
$lang['AdminCompanyGroups.!error.delete_failed'] = '%1$s je výchozí skupina a nelze ji odstranit.';
$lang['AdminCompanyGroups.!success.delete_deleted'] = '%1$s byl úspěšně smazán!';
$lang['AdminCompanyGroups.!success.edit_updated'] = '%1$s bylo úspěšně upraveno!';
$lang['AdminCompanyGroups.!success.add_created'] = '%1$s byl úspěšně vytvořen!';

==> blesta-5.11.4.zip: blesta/language/cs_cz/admin_company_groups.php <==
<?php
/**
 * Admin Company Groups
 *
 * @package blesta
 * @subpackage blesta.language.cs_cz
 * @copyright Copyright (c) 2025, Phillips Data, Inc.
 * @license http://www.blesta.com/license/ The Blesta License Agreement
 * @link http://www.blesta.com/ Blesta
 */

$lang['AdminCompanyGroups.edit.text_editsubmit'] = 'Upravit skupinu';
$lang['AdminCompanyGroups.edit.field_force_email_usernames'] = 'Vynucování e-mailových adres jako uživatelských jmen';
$lang['AdminCompanyGroups.edit.field_company_settings'] = 'Použít nastavení společnosti (zrušte zaškrtnutí a zadejte níže)';
$lang['AdminCompanyGroups.edit.field_delivery_methods'] = 'Způsoby doručování faktur';
$lang['AdminCompanyGroups.edit.field_description'] = 'Popis';
$lang['AdminCompanyGroups.edit.field_color'] = 'Barva';
$lang['AdminCompanyGroups.edit.field_name'] = 'Název';
$lang['AdminCompanyGroups.edit.heading_client_fields'] = 'Povinná pole klienta';
$lang['AdminCompanyGroups.edit.heading_client_settings'] = 'Obecná nastavení klienta';
$lang['AdminCompanyGroups.edit.heading_payment'] = 'Oznámení';
$lang['AdminCompanyGroups.edit.heading_delivery'] = 'Dodání faktury';
$lang['AdminCompanyGroups.edit.heading_late_fees'] = 'Poplatky za zpoždění';
$lang['AdminCompanyGroups.edit.heading_invoice'] = 'Možnosti fakturace a účtování';
$lang['AdminCompanyGroups.edit.heading_basic'] = 'Základní možnosti';
$lang['AdminCompanyGroups.edit.boxtitle_editgroup'] = 'Upravit skupinu';
$lang['AdminCompanyGroups.edit.page_title'] = 'Nastavení > Společnost > Skupiny klientů > Upravit skupinu';
$lang['AdminCompanyGroups.add.text_addsubmit'] = 'Vytvořit skupinu';
$lang['AdminCompanyGroups.add.field_email_verification'] = 'Povolení ověřování e-mailu';
$lang['AdminCompanyGroups.add.field_force_email_usernames'] = 'Vynucování e-mailových adres jako uživatelských jmen';
$lang['AdminCompanyGroups.add.field_company_settings'] = 'Použít nastavení společnosti (zrušte zaškrtnutí a zadejte níže)';
$lang['AdminCompanyGroups.add.field_delivery_methods'] = 'Způsoby doručování faktur';
$lang['AdminCompanyGroups.add.field_description'] = 'Popis';
$lang['AdminCompanyGroups.add.field_color'] = 'Barva';
$lang['AdminCompanyGroups.add.field_name'] = 'Název';
$lang['AdminCompanyGroups.add.heading_client_fields'] = 'Povinná pole klienta';
$lang['AdminCompanyGroups.add.heading_client_settings'] = 'Obecná nastavení klienta';
$lang['AdminCompanyGroups.add.heading_payment'] = 'Oznámení';
$lang['AdminCompanyGroups.add.heading_delivery'] = 'Dodání faktury';
$lang['AdminCompanyGroups.add.heading_late_fees'] = 'Poplatky za zpoždění';
$lang['AdminCompanyGroups.add.heading_invoice'] = 'Možnosti fakturace a účtování';
$lang['AdminCompanyGroups.add.heading_basic'] = 'Základní možnosti';
$lang['AdminCompanyGroups.add.boxtitle_addgroup'] = 'Vytvořit skupinu';
$lang['AdminCompanyGroups.add.page_title'] = 'Nastavení > Společnost > Skupiny klientů > Vytvořit skupinu';
$lang['AdminCompanyGroups.index.confirm_delete'] = 'Opravdu chcete tuto skupinu klientů odstranit? Všichni klienti v této skupině budou přesunuti do výchozí skupiny.';
$lang['AdminCompanyGroups.index.no_results'] = 'Neexistují žádné skupiny klientů.';
$lang['AdminCompanyGroups.index.option_delete'] = 'Odstranit';
$lang['AdminCompanyGroups.index.option_edit'] = 'Upravit';
$lang['AdminCompanyGroups.index.text_options'] = 'Možnosti';
$lang['AdminCompanyGroups.index.text_clients'] = 'Počet klientů';
$lang['AdminCompanyGroups.index.text_description'] = 'Popis';
$lang['AdminCompanyGroups.index.text_name'] = 'Název';
$lang['AdminCompanyGroups.index.categorylink_addgroup'] = 'Vytvořit skupinu';
$lang['AdminCompanyGroups.index.boxtitle_groups'] = 'Skupiny klientů';
$lang['AdminCompanyGroups.index.page_title'] = 'Nastavení > Společnost > Skupiny klientů';
$lang['AdminCompanyGroups.!tooltip.email_verification'] = 'Zaškrtněte, chcete-li odeslat ověřovací e-mail při vytvoření nového přihlášení nebo při změně e-mailu klienta. Oznámení se bude zobrazovat na profilu klienta, dokud nebude ověřen.';
$lang['AdminCompanyGroups.!tooltip.force_email_usernames'] = 'Odstraňuje možnost klientů definovat vlastní uživatelské jméno.';
$lang['AdminCompanyGroups.!error.delete_failed'] = '%1$s je výchozí skupina a nelze ji odstranit.';
$lang['AdminCompanyGroups.!success.delete_deleted'] = '%1$s byl úspěšně smazán!';
$lang['AdminCompanyGroups.!success.edit_updated'] = '%1$s bylo úspěšně upraveno!';
$lang['AdminCompanyGroups.!success.add_created'] = '%1$s byl úspěšně vytvořen!';
$lang['AdminCompanyGroups.edit.heading_gateway_restrictions'] = 'Povolené brány';
$lang['AdminCompanyGroups.add.heading_gateway_restrictions'] = 'Povolené brány';
